==> chronojump-0.9.4.tar.xz: chronojump-0.9.4/src/stats/graphs/runSimple.cs <==
/*
 * This file is part of ChronoJump
 *
 * ChronoJump is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or   
 *    (at your option) any later version.
 *    
 * ChronoJump is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *    GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
 */

using System;
using System.Data;
using Gtk;
using System.Collections; //ArrayList
using System.Drawing;
using System.Drawing.Imaging;
using Mono.Unix;


public class GraphRunSimple : StatRunSimple
{
	protected string operation;

	//for simplesession
	GraphSerie serieSpeed;
	GraphSerie serieDistance;
	GraphSerie serieTime;
	
	public GraphRunSimple (StatTypeStruct myStatTypeStruct)
	{
		completeConstruction (myStatTypeStruct, treeview);
		
		this.dataColumns = 3; //for Simplesession
		
		if (statsJumpsType == 2) {
			this.operation = "MAX";
		} else {
			this.operation = "AVG";
		}

		CurrentGraphData.WindowTitle = Catalog.GetString("ChronoJump graph");
		//title is shown on the graph except it's a report, then title will be on the html
		if(myStatTypeStruct.ToReport) {
			CurrentGraphData.GraphTitle = "";
		} else {
			CurrentGraphData.GraphTitle = "Simple runs";
		}
		
		if(sessions.Count == 1) {
			//four series, the four columns
			serieSpeed = new GraphSerie();
			serieDistance = new GraphSerie();
			serieTime = new GraphSerie();
				
			serieSpeed.Title = Catalog.GetString("Speed");
			serieDistance.Title = Catalog.GetString("Distance");
			serieTime.Title = Catalog.GetString("Time");;
			
			serieSpeed.IsLeftAxis = true;
			serieDistance.IsLeftAxis = false;
			serieTime.IsLeftAxis = false;

			CurrentGraphData.LabelLeft = Catalog.GetString("Speed") + "(m/s)";
			CurrentGraphData.LabelRight = 
				Catalog.GetString("Distance") + "(m), " +
				Catalog.GetString("Time") + "(s)";
		} else {
			for(int i=0; i < sessions.Count ; i++) {
				string [] stringFullResults = sessions[i].ToString().Split(new char[] {':'});
				CurrentGraphData.XAxisNames.Add(stringFullResults[1].ToString());
			}
			CurrentGraphData.LabelLeft = Catalog.GetString("Speed") + "(s)";
			CurrentGraphData.LabelRight = "";
		}
	}

	protected override void printData (string [] statValues) 
	{
		//values are recorded for calculating later AVG and SD
		recordStatValues(statValues);

		if(sessions.Count == 1) {
			int i=0;
			bool foundAVG = false;
			//we need to save this transposed
			foreach (string myValue in statValues) {
				if(i == 0) {
					//don't plot AVG and SD rows
					if( myValue == Catalog.GetString("AVG")) 
						foundAVG = true;
					else
						CurrentGraphData.XAxisNames.Add(myValue);
				} else if(i == 1) {
					if(foundAVG)
						serieSpeed.Avg = Convert.ToDouble(myValue);
					else
						serieSpeed.SerieData.Add(myValue);
				} else if(i == 2) {
					if(foundAVG)
						serieDistance.Avg = Convert.ToDouble(myValue);
					else
						serieDistance.SerieData.Add(myValue);
				} else if(i == 3) {
					if(foundAVG)
						serieTime.Avg = Convert.ToDouble(myValue);
					else
						serieTime.SerieData.Add(myValue);
				} 

				if(foundAVG && i == dataColumns) {
					//add created series to GraphSeries ArrayList
					//check don't do it two times
					if(GraphSeries.Count == 0) {
						GraphSeries.Add(serieSpeed);
						GraphSeries.Add(serieDistance);
						GraphSeries.Add(serieTime);
					}
					return;
				}

				i++;
			}
		} else {
			GraphSerie mySerie = new GraphSerie();
			mySerie.IsLeftAxis = true;

			int i=0;
			foreach (string myValue in statValues) {
				if( myValue == Catalog.GetString("SD") ) 
					return;
				
				if(i == 0) 
					mySerie.Title = myValue;
				else if( i == sessions.Count + 1 ) { //eg, for 2 sessions: [(0)person name, (1)sess1, (2)sess2, (3)AVG]
					if(myValue != "-")
						mySerie.Avg = Convert.ToDouble(myValue);
				} else 
					mySerie.SerieData.Add(myValue);
				
				i++;
			}
			GraphSeries.Add(mySerie);
		}
	}
}

==> chronojump-1.4.9.tar.xz: chronojump-1.4.9/src/stats/graphs/runSimple.cs <==
/*
 * This file is part of ChronoJump
 *
 * ChronoJump is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or   
 *    (at your option) any later version.
 *    
 * ChronoJump is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *    GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
 */

using System;
using System.Data;
using Gtk;
using System.Collections; //ArrayList
using System.Drawing;
using System.Drawing.Imaging;
using Mono.Unix;


public class GraphRunSimple : StatRunSimple
{
	protected string operation;

	//for simplesession
	GraphSerie serieSpeed;
	GraphSerie serieDistance;
	GraphSerie serieTime;
	
	public GraphRunSimple (StatTypeStruct myStatTypeStruct)
	{
		completeConstruction (myStatTypeStruct, treeview);
		
		this.dataColumns = 3; //for Simplesession
		
		if (statsJumpsType == 2) {
			this.operation = "MAX";
		} else {
			this.operation = "AVG";
		}

		CurrentGraphData.WindowTitle = Catalog.GetString("ChronoJump graph");
		//title is shown on the graph except it's a report, then title will be on the html
		if(myStatTypeStruct.ToReport) {
			CurrentGraphData.GraphTitle = "";
		} else {
			CurrentGraphData.GraphTitle = "Simple runs";
		}
		
		if(sessions.Count == 1) {
			//four series, the four columns
			serieSpeed = new GraphSerie();
			serieDistance = new GraphSerie();
			serieTime = new GraphSerie();
				
			serieSpeed.Title = translateYesNo("Speed");
			serieDistance.Title = translateYesNo("Distance");
			serieTime.Title = translateYesNo("Time");;
			
			serieSpeed.IsLeftAxis = true;
			serieDistance.IsLeftAxis = false;
			serieTime.IsLeftAxis = false;

			CurrentGraphData.LabelLeft = translateYesNo("Speed") + "(m/s)";
			CurrentGraphData.LabelRight = 
				translateYesNo("Distance") + "(m), " +
				translateYesNo("Time") + "(s)";
		} else {
			for(int i=0; i < sessions.Count ; i++) {
				string [] stringFullResults = sessions[i].ToString().Split(new char[] {':'});
				CurrentGraphData.XAxisNames.Add(stringFullResults[1].ToString());
			}
			CurrentGraphData.LabelLeft = translateYesNo("Speed") + "(s)";
			CurrentGraphData.LabelRight = "";
		}
	}

	protected override void printData (string [] statValues) 
	{
		//values are recorded for calculating later AVG and SD
		recordStatValues(statValues);

		if(sessions.Count == 1) {
			int i=0;
			bool foundAVG = false;
			//we need to save this transposed
			foreach (string myValue in statValues) {
				if(i == 0) {
					//don't plot AVG and SD rows
					if( myValue == Catalog.GetString("AVG")) 
						foundAVG = true;
					else
						CurrentGraphData.XAxisNames.Add(myValue);
				} else if(i == 1) {
					if(foundAVG)
						serieSpeed.Avg = Convert.ToDouble(myValue);
					else
						serieSpeed.SerieData.Add(myValue);
				} else if(i == 2) {
					if(foundAVG)
						serieDistance.Avg = Convert.ToDouble(myValue);
					else
						serieDistance.SerieData.Add(myValue);
				} else if(i == 3) {
					if(foundAVG)
						serieTime.Avg = Convert.ToDouble(myValue);
					else
						serieTime.SerieData.Add(myValue);
				} 

				if(foundAVG && i == dataColumns) {
					//add created series to GraphSeries ArrayList
					//check don't do it two times
					if(GraphSeries.Count == 0) {
						GraphSeries.Add(serieSpeed);
						GraphSeries.Add(serieDistance);
						GraphSeries.Add(serieTime);
					}
					return;
				}

				i++;
			}
		} else {
			GraphSerie mySerie = new GraphSerie();
			mySerie.IsLeftAxis = true;

			int i=0;
			foreach (string myValue in statValues) {
				if( myValue == Catalog.GetString("SD") ) 
					return;
				
				if(i == 0) 
					mySerie.Title = myValue;
				else if( i == sessions.Count + 1 ) { //eg, for 2 sessions: [(0)person name, (1)sess1, (2)sess2, (3)AVG]
					if(myValue != "-")
						mySerie.Avg = Convert.ToDouble(myValue);
				} else 
					mySerie.SerieData.Add(myValue);
				
				i++;
			}
			GraphSeries.Add(mySerie);
		}
	}
}
